category property
(iOS Only) The category for this notification. This can trigger custom behavior (ie. if this notification should display a custom Content Extension for custom UI)
Implementation
String? category;
(iOS Only) The category for this notification. This can trigger custom behavior (ie. if this notification should display a custom Content Extension for custom UI)
String? category;