groupedNotifications property
(Android Only) Summary notifications grouped Notification payload will have the most recent notification received.
Implementation
List<OSNotification>? groupedNotifications;
(Android Only) Summary notifications grouped Notification payload will have the most recent notification received.
List<OSNotification>? groupedNotifications;